var express = require('express');
var path = require('path');
var diag = require('diagram');

var app = express();

// serve static files from client directory
app.use(express.static('client'));

// collect body as a raw string instead of using body-parser
// as Digram.fromJson expects the whole string
app.use(
    function (req, res, next)
    {
        req.setEncoding('utf8');
        req.rawBody = '';
        req.on('data', function(chunk) { req.rawBody += chunk; });
        req.on('end', function() { next(); });
    }
);

var MindFusion = diag.MindFusion;
var Diagram = MindFusion.Diagramming.Diagram;

// the sample posts diagram JSON to this URL
app.post('/diagram', function(req, res)
{
    // won't be required in final release
    var dummyCanvas = { parentNode:{} };

    // create Diagram instance
    var diagram = new Diagram(dummyCanvas);

    // load diagram elements drawn by user
    diagram.fromJson(req.rawBody);

    // examine diagram contents
    console.log(diagram.nodes.length + " nodes");
    console.log(diagram.links.length + " links");
    diagram.nodes.forEach(function (node, index)
    {
        console.log("node " + index + ": " + node.getText());
    });

    // send some response
    res.send('ok');
});

// the sample gets diagram JSON from this URL
app.get('/diagram', function(req, res)
{
    // won't be required in final release
    var dummyCanvas = { parentNode:{} };

    // create Diagram instance
    var diagram = new Diagram(dummyCanvas);

    // create some diagram items
    var node1 = diagram.getFactory().createShapeNode(10, 10, 40, 30);
    var node2 = diagram.getFactory().createShapeNode(60, 10, 40, 30);
    var link = diagram.getFactory().createDiagramLink(node1, node2);

    // set nodes' content
    node1.setText("node.js");
    node1.setBrush("orange");
    node2.setText("hello there");

    // send diagram json
    res.send(
        diagram.toJson());
});

app.listen(1234);